==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/kmod/search/index.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");
include("$CONF[G_PATH]/include/kmod/search/lang/$CONF[Language]". ".php");

function KWL_drawSearch($query) {

   $CONF = KWL_GetConf();
   list($topic,$what,$limit,$time,$regex,$story) = KWL_UserVars(array('topic','what','limit','time','regex','story'),"trim");

   if (empty($limit)) $limit = 30;

   if ($story) {
      $A = KWL_GetStory($story);
      $VAR['Heading'] = _CSEARCH;
      if (empty($what)) $what = "comments";
      $find_array = array ("comments" => _COMMENTS, "cauthors" => _AUTHORS);
   } else {
      if (empty($what)) $what = "stories";
      $VAR['Heading'] = KWL_PrepareHtml($CONF['SiteName']) .": ". _SEARCH;
      $find_array = array ("stories"  => _STORIES, "comments" => _COMMENTS, "authors"  => _AUTHORS ."(". _STORIES .")", "cauthors" => _AUTHORS ."(". _COMMENTS .")");
   }
   
   $out = new KWL_Html;
   $VAR['Content'] = $out->form_start("search.php","find",0,"GET").
      $out->table_start("100%",'',0,0,3).
      ($story ? "<tr><td>". _TITLE .":</td><td><A HREF=\"stories.php?story=$story\">$A[Heading]</A>". $out->input_form("hidden","story",$story) ."</td>" : "").
      "<tr><td>". _SEARCHFOR .":</td>".
      "<td>". $out->input_form("text","query",KWL_PrepareHtml($query),KWL_FormSize(20),35) . "</td></tr>\n".
      (empty($story) ? 
      "<tr><td>". _TOPIC .":</td>".
      "<td>". $out->topicsel($topic,"search","topic").
      "</td><tr>\n" : "").
      "<tr><td>". _QUERY .":</td>".
      "<td>". $out->radio("what",$find_array,$what).
      "</td></tr>".
      "<tr><td>". _LIMIT . ":</td><td>".
      $out->select("limit",array ( "none" => _NONE,
                                       10 => 10,
                                       20 => 20,
                                       30 => 30,
                                       40 => 40,
                                       50 => 50 ),
                    $limit).
      "</tr><tr><td>". _PERIOD .":</td><td>".
      $out->select("time",array ( 7 => _WEEK,
                                 14 => _2WEEK,
                                 30 => _MONTH,
                                 60 => _2MONTH,
                                 90 => _3MONTH,
                                 0  => _ALL ),
                    $time).
      "</td></tr><tr><td colspan=2>".
      $out->input_form("submit",'',_SEARCH) ."&nbsp;&nbsp;".
      _REGEX ."&nbsp;". $out->check_box("regex",$regex).
      "</td></tr>". $out->table_end() . $out->form_end();
   
   KWL_DrawMain($VAR);
}

function KWL_drawResults($query,$month='',$year='') {
   global $TOPIC;
   $CONF = KWL_GetConf();
   list($topic,$what,$limit,$time,$regex,$story) = KWL_UserVars(array('topic','what','limit','time','regex','story'),"trim");

   if ($limit == "none" || !$limit) $lsql = "";
   else $lsql = "LIMIT $limit";
   if ($time) $tquery = "AND TO_DAYS(NOW()) - TO_DAYS(Birthstamp) <= $time ";
   else  $tquery = "";
   $query = str_replace("%","\%",$query);
   
   if ($regex) {

      $chk = preg_replace("/\\\([\]\[()])/i","",$query);
      $chk = preg_replace("/[^\[\]()]/i","",$chk);
      
      $chkAOpen = strlen(preg_replace("/\]/i","",$chk));
      $chkAClos = strlen(preg_replace("/\[/i","",$chk));
      $chkBOpen = strlen(preg_replace("/\)/i","",$chk));
      $chkBClos = strlen(preg_replace("/\(/i","",$chk));

      if($chkAOpen !== $chkAClos) $query .= "]";
      elseif($chkBOpen !== $chkBClos) $query .= ")";
      
      $rquery = "REGEXP '$query'";
   
   } else {
      
      $rquery = "LIKE '%$query%'";

   }
   
   switch ($what) {
      case "comments";
         $sql  = "SELECT * FROM T_Comments WHERE (Content $rquery) $tquery";
         if ($story) $sql .= "AND TopRid = '$story' ";
         $sql .= "ORDER BY Timestamp DESC $lsql";
         $result = SqlQuery($sql);
         KWL_drawCsearchResult($result,$query);
      break;

      case "cauthors";
         $sql  = "SELECT * FROM T_Comments WHERE (Author $rquery) $tquery";
         if ($story) $sql .= "AND TopRid = '$story' ";
         $sql .= "ORDER BY Birthstamp desc $lsql";
         $result = SqlQuery($sql);
         KWL_drawCsearchResult($result,$query);
      break;
      
      case "authors":
         $sql  = "SELECT * FROM T_Stories WHERE ";
         $sql .= "(Author $rquery) $tquery";
         $sql .= "AND Verified = 'Y' ";
         if ($topic>0) $sql .= "AND Topic = $topic ";
         $sql .= "ORDER BY Repostamp DESC $lsql";
         $result = SqlQuery($sql);
         
         if (mysql_num_rows($result)) {
            $i = 1;
            $VAR['Content'] = "<TABLE CELLPADDING=1 CELLSPACING=5 BORDER=0 WIDTH=\"99%\">\n";
            while ($A = mysql_fetch_array($result)) {
               $topic = $TOPIC[$A['Topic']]['Topic'];
               $VAR[Content] .= "<tr><td align=left><b>$i.</b> ".
                  "<a href=\"stories.php?story=$A[Rid]\"><b>$A[Heading]</b></a>".
                  " (<a href=\"stories.php?topic=$A[Topic]\">". KWL_PrepareHtml($topic) ."</a>) ".
                  _BY ." ". KWL_Author($A) .
                  "<br><font size=\"-1\">". _COMMENTS ." $A[replys],".
                  " ". _POSTEDON ." " . KWL_DateFormat($A['Repostamp']) ."</font>".
                  "</td></tr>\n";
               $i++;
            }
            $VAR['Content'] .= "</table>\n";
            $VAR['Heading'] = _SEARCHRESULTS . ": ". $nrows ." ". _MATCHES ." \"" . KWL_PrepareHtml($query) ."\"\n";
         } else {
            $VAR['Heading'] = _SEARCHRESULTS;
            $VAR['Content'] = "<br>" . _NOMATCHES . "<br><br>";
         }
         KWL_DrawMain($VAR);
      break;

      default:

         if (defined("_ARCHIVE_RESULT")) {
            $sql  = "SELECT * FROM T_Stories WHERE (month(Repostamp) = '$month' ".
                    "AND year(Repostamp) = '$year') ";
         } else {
            $sql = "SELECT * FROM T_Stories WHERE ".
                   "(Content $rquery OR Heading $rquery OR Summary $rquery) $tquery";
         }

         $sql .= "AND Verified = 'Y' ";
         if ($topic) $sql .= "AND Topic = $topic ";
         $sql .= "ORDER BY Repostamp DESC $lsql";
         $result = SqlQuery($sql);
         
         if (mysql_num_rows($result)) {
$VAR["Content"] = "<table cellpadding=1 cellspacing=5 border=0 width=\"99%\">\n";
            $i = 1;
         while ($A = mysql_fetch_array($result)) {
            $topic = $TOPIC[$A['Topic']]['Topic'];
            $VAR['Content'] .= "<tr><td><b>$i.</b> ".
               "<a href=\"stories.php?story=$A[Rid]\"><b>$A[Heading]</b></a>".
               " (<a href=\"stories.php?topic=$A[Topic]\">$topic</a>) ".
               _BY ." ". KWL_Author($A) .
               "<br><font size=\"-1\">". _COMMENTS ." $A[replys],".
               " ". _POSTEDON ." ". KWL_DateFormat($A['Repostamp']) ."</font>".
               "</td></tr>\n";
            $i++;
         }
         $VAR['Content'] .= "</table>\n";
         if (defined("_ARCHIVE_RESULT")) $VAR['Heading'] = _ARCHIVE;
         else $VAR['Heading'] = _SEARCHRESULTS . ": $i". _MATCHES . " \"". KWL_PrepareHtml($query) ."\"\n";
         } else {
            $VAR['Heading'] = _SEARCHRESULTS;
            $VAR['Content'] = "<br>" . _NOMATCHES . "<br><br>";
         }
         KWL_DrawMain($VAR);
      
      break;
   }
}

function KWL_drawCsearchResult($result,$query) {

   if (mysql_num_rows($result)) {
      $i = 1;
      $VAR['Content'] = "<TABLE CELLPADDING=1 CELLSPACING=5 BORDER=0 WIDTH=\"99%\">\n";
      while ($A = mysql_fetch_array($result)) {
         $VAR['Content'] .= "<TR>\n<TD ALIGN=LEFT>\n<B>$i.</B> ";
         $title = "<b>". KWL_PrepareHtml(KWL_StringCut($A['Content'],50)) . "...</b>";
         
         if (SqlCount("T_Stories","Rid",$A['TopRid'])) {
            $VAR['Content'] .= "<a href=\"comments.php?rid=$A[ParentRid]&story=$A[TopRid]#$A[Rid]\">$title</a>";
         } elseif (SqlCount("T_PollQuestions","Rid",$A['TopRid'])) {
            $VAR['Content'] .= "<a href=\"pollbooth.php?poll=$A[TopRid]&aid=-1#$A[Rid]\">$title</a>";
         } else {
            $VAR['Content'] .= "<a href=\"pages.php?page=$A[TopRid]#$A[Rid]\">$title</a>";
         }

         $VAR['Content'] .= "<br><font size=\"-1\">". _POSTEDBY ." ". KWL_Author($A) .
                          " ". _ON ." ". KWL_DateFormat($A['Birthstamp']) ."</font>".
                          "</td></tr>\n";
         $i++;
      }
      $VAR['Content'] .= "</table>\n";
      $VAR['Heading'] = _SEARCHRESULTS . ": $i ". _MATCHES . " \"" . KWL_PrepareHtml($query) ."\"\n";
   } else {
      $VAR['Heading'] = _SEARCHRESULTS;
      $VAR['Content'] = "<br>". _NOMATCHES ."<br><br>";
   }
   KWL_DrawMain($VAR);
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/kmod/search/index.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");
include("$CONF[G_PATH]/include/kmod/search/lang/$CONF[Language]". ".php");

function KWL_drawSearch($query) {

   $CONF = KWL_GetConf();
   list($topic,$what,$limit,$time,$regex,$story) = KWL_UserVars(array('topic','what','limit','time','regex','story'),"trim");

   if (empty($limit)) $limit = 30;

   if ($story) {
      $A = KWL_GetStory($story);
      $VAR['Heading'] = _CSEARCH;
      if (empty($what)) $what = "comments";
      $find_array = array ("comments" => _COMMENTS, "cauthors" => _AUTHORS);
   } else {
      if (empty($what)) $what = "stories";
      $VAR['Heading'] = KWL_PrepareHtml($CONF['SiteName']) .": ". _SEARCH;
      $find_array = array ("stories"  => _STORIES, "comments" => _COMMENTS, "authors"  => _AUTHORS ."(". _STORIES .")", "cauthors" => _AUTHORS ."(". _COMMENTS .")");
   }
   
   $out = new KWL_Html;
   $VAR['Content'] = $out->form_start("search.php","find",0,"GET").
      $out->table_start("100%",'',0,0,3).
      ($story ? "<tr><td>". _TITLE .":</td><td><A HREF=\"stories.php?story=$story\">$A[Heading]</A>". $out->input_form("hidden","story",$story) ."</td>" : "").
      "<tr><td>". _SEARCHFOR .":</td>".
      "<td>". $out->input_form("text","query",KWL_PrepareHtml($query),KWL_FormSize(20),35) . "</td></tr>\n".
      (empty($story) ? 
      "<tr><td>". _TOPIC .":</td>".
      "<td>". $out->topicsel($topic,"search","topic").
      "</td><tr>\n" : "").
      "<tr><td>". _QUERY .":</td>".
      "<td>". $out->radio("what",$find_array,$what).
      "</td></tr>".
      "<tr><td>". _LIMIT . ":</td><td>".
      $out->select("limit",array ( "none" => _NONE,
                                       10 => 10,
                                       20 => 20,
                                       30 => 30,
                                       40 => 40,
                                       50 => 50 ),
                    $limit).
      "</tr><tr><td>". _PERIOD .":</td><td>".
      $out->select("time",array ( 7 => _WEEK,
                                 14 => _2WEEK,
                                 30 => _MONTH,
                                 60 => _2MONTH,
                                 90 => _3MONTH,
                                 0  => _ALL ),
                    $time).
      "</td></tr><tr><td colspan=\"2\">".
      $out->input_form("submit",'',_SEARCH) ."&nbsp;&nbsp;".
      _REGEX ."&nbsp;". $out->check_box("regex",$regex).
      "</td></tr>". $out->table_end() . $out->form_end();
   
   KWL_DrawMain($VAR);
}

function KWL_drawResults($query,$month='',$year='') {
   global $TOPIC;
   $CONF = KWL_GetConf();
   list($topic,$what,$limit,$time,$regex,$story) = KWL_UserVars(array('topic','what','limit','time','regex','story'),"trim");

   if ($limit == "none" || !$limit) $lsql = "";
   else $lsql = "LIMIT $limit";
   if ($time) $tquery = "AND TO_DAYS(NOW()) - TO_DAYS(Birthstamp) <= $time ";
   else  $tquery = "";
   $query = str_replace("%","\%",$query);
   
   if ($regex) {

      $chk = preg_replace("/\\\([\]\[()])/i","",$query);
      $chk = preg_replace("/[^\[\]()]/i","",$chk);
      
      $chkAOpen = strlen(preg_replace("/\]/i","",$chk));
      $chkAClos = strlen(preg_replace("/\[/i","",$chk));
      $chkBOpen = strlen(preg_replace("/\)/i","",$chk));
      $chkBClos = strlen(preg_replace("/\(/i","",$chk));

      if($chkAOpen !== $chkAClos) $query .= "]";
      elseif($chkBOpen !== $chkBClos) $query .= ")";
      
      $rquery = "REGEXP '$query'";
   
   } else {
      
      $rquery = "LIKE '%$query%'";

   }
   
   switch ($what) {
      case "comments";
         $sql  = "SELECT * FROM T_Comments WHERE (Content $rquery) $tquery";
         if ($story) $sql .= "AND TopRid = '$story' ";
         $sql .= "ORDER BY Timestamp DESC $lsql";
         $result = SqlQuery($sql);
         KWL_drawCsearchResult($result,$query);
      break;

      case "cauthors";
         $sql  = "SELECT * FROM T_Comments WHERE (Author $rquery) $tquery";
         if ($story) $sql .= "AND TopRid = '$story' ";
         $sql .= "ORDER BY Birthstamp desc $lsql";
         $result = SqlQuery($sql);
         KWL_drawCsearchResult($result,$query);
      break;
      
      case "authors":
         $sql  = "SELECT * FROM T_Stories WHERE ";
         $sql .= "(Author $rquery) $tquery";
         $sql .= "AND Verified = 'Y' ";
         if ($topic>0) $sql .= "AND Topic = $topic ";
         $sql .= "ORDER BY Repostamp DESC $lsql";
         $result = SqlQuery($sql);
         
         if (mysql_num_rows($result)) {
            $i = 1;
            $VAR['Content'] = "<TABLE CELLPADDING=1 CELLSPACING=5 BORDER=0 WIDTH=\"99%\">\n";
            while ($A = mysql_fetch_array($result)) {
               $topic = $TOPIC[$A['Topic']]['Topic'];
               $VAR[Content] .= "<tr><td align=\"left\"><b>$i.</b> ".
                  "<a href=\"stories.php?story=$A[Rid]\"><b>$A[Heading]</b></a>".
                  " (<a href=\"stories.php?topic=$A[Topic]\">". KWL_PrepareHtml($topic) ."</a>) ".
                  _BY ." ". KWL_Author($A) .
                  "<br />". _COMMENTS ." $A[replys],".
                  " ". _POSTEDON ." " . KWL_DateFormat($A['Repostamp']) .
                  "</td></tr>\n";
               $i++;
            }
            $VAR['Content'] .= "</table>\n";
            $VAR['Heading'] = _SEARCHRESULTS . ": ". $nrows ." ". _MATCHES ." \"" . KWL_PrepareHtml($query) ."\"\n";
         } else {
            $VAR['Heading'] = _SEARCHRESULTS;
            $VAR['Content'] = "<br />" . _NOMATCHES . "<br /><br />";
         }
         KWL_DrawMain($VAR);
      break;

      default:

         if (defined("_ARCHIVE_RESULT")) {
            $sql  = "SELECT * FROM T_Stories WHERE (month(Repostamp) = '$month' ".
                    "AND year(Repostamp) = '$year') ";
         } else {
            $sql = "SELECT * FROM T_Stories WHERE ".
                   "(Content $rquery OR Heading $rquery OR Summary $rquery) $tquery";
         }

         $sql .= "AND Verified = 'Y' ";
         if ($topic) $sql .= "AND Topic = $topic ";
         $sql .= "ORDER BY Repostamp DESC $lsql";
         $result = SqlQuery($sql);
         
         if (mysql_num_rows($result)) {
$VAR["Content"] = "<table cellpadding=1 cellspacing=5 border=0 width=\"99%\">\n";
            $i = 1;
         while ($A = mysql_fetch_array($result)) {
            $topic = $TOPIC[$A['Topic']]['Topic'];
            $VAR['Content'] .= "<tr><td><b>$i.</b> ".
               "<a href=\"stories.php?story=$A[Rid]\"><b>$A[Heading]</b></a>".
               " (<a href=\"stories.php?topic=$A[Topic]\">$topic</a>) ".
               _BY ." ". KWL_Author($A) .
               "<br />". _COMMENTS ." $A[replys],".
               " ". _POSTEDON ." ". KWL_DateFormat($A['Repostamp']) .
               "</td></tr>\n";
            $i++;
         }
         $VAR['Content'] .= "</table>\n";
         if (defined("_ARCHIVE_RESULT")) $VAR['Heading'] = "<a name=\"result\">" . _ARCHIVE . "</a>";
         else $VAR['Heading'] = _SEARCHRESULTS . ": $i". _MATCHES . " \"". KWL_PrepareHtml($query) ."\"\n";
         } else {
            $VAR['Heading'] = _SEARCHRESULTS;
            $VAR['Content'] = "<br />" . _NOMATCHES . "<br /><br />";
         }
         KWL_DrawMain($VAR);
      
      break;
   }
}

function KWL_drawCsearchResult($result,$query) {

   if (mysql_num_rows($result)) {
      $i = 1;
      $VAR['Content'] = "<table cellpadding=\"1\" cellspacing=\"5\" border=\"0\" width=\"99%\">\n";
      while ($A = mysql_fetch_array($result)) {
         $VAR['Content'] .= "<tr>\n<td align=\"left\">\n<b>$i.</b> ";
         $title = "<b>". KWL_PrepareHtml(KWL_StringCut($A['Content'],50)) . "...</b>";
         
         if (SqlCount("T_Stories","Rid",$A['TopRid'])) {
            $VAR['Content'] .= "<a href=\"comments.php?rid=$A[ParentRid]&amp;story=$A[TopRid]#$A[Rid]\">$title</a>";
         } elseif (SqlCount("T_PollQuestions","Rid",$A['TopRid'])) {
            $VAR['Content'] .= "<a href=\"pollbooth.php?poll=$A[TopRid]&amp;aid=-1#$A[Rid]\">$title</a>";
         } else {
            $VAR['Content'] .= "<a href=\"pages.php?page=$A[TopRid]#$A[Rid]\">$title</a>";
         }

         $VAR['Content'] .= "<br />". _POSTEDBY ." ". KWL_Author($A) .
                          " ". _ON ." ". KWL_DateFormat($A['Birthstamp']) .
                          "</td></tr>\n";
         $i++;
      }
      $VAR['Content'] .= "</table>\n";
      $VAR['Heading'] = _SEARCHRESULTS . ": $i ". _MATCHES . " \"" . KWL_PrepareHtml($query) ."\"\n";
   } else {
      $VAR['Heading'] = _SEARCHRESULTS;
      $VAR['Content'] = "<br />". _NOMATCHES ."<br /><br />";
   }
   KWL_DrawMain($VAR);
}
?>
